# distribution specific definitions
%define use_systemd (0%{?fedora} && 0%{?fedora} >= 18) || (0%{?rhel} && 0%{?rhel} >= 7) || (0%{?suse_version} == 1315)

Name:           hiawatha
Version:        10.8.3
Release:        2%{?dist}
Summary:        An advanced and secure web-server for Unix
License:        GPLv2
Group:          System Environment/Daemons
URL:            https://www.hiawatha-webserver.org/
Source0:        https://www.hiawatha-webserver.org/files/%{name}-%{version}.tar.gz
#Source1:        https://unknown-domain.no-ip.net/pkg/hiawatha/hiawatha.service.tar.gz

BuildRoot:      %{_topdir}/BUILDROOT/
Requires(pre):  shadow-utils
BuildRequires:  cmake3,make,gcc,glibc-devel,libxml2-devel,libxslt-devel,pkcs11-helper-devel

%if 0%{?rhel} == 6
Requires: initscripts >= 8.36
Requires(post): chkconfig
%endif

%if 0%{?rhel} == 7
BuildRequires: systemd-units,redhat-lsb-core,systemd
Requires: systemd
%endif

%description
Hiawatha is a web-server with the three key attributes: secure, easy-to-use, 
and lightweight.

%package        extra
Summary:        Extra tools for Hiawatha Web Server
Group:          Applications/Internet
Requires:       %{name} = %{version}-%{release},php-process

%description    extra
This package contains extra scripts written for Hiawatha Web Server, such as 
an integration system for Let's Encrypt.

%prep
%setup -q
#%setup -D -a 1

%build
CFLAGS="${CFLAGS:-%optflags}" ; export CFLAGS
CXXFLAGS="${CXXFLAGS:-%optflags}" ; export CXXFLAGS
FFLAGS="${FFLAGS:-%optflags}" ; export FFLAGS
cmake3 -DCMAKE_INSTALL_PREFIX="" -DCMAKE_INSTALL_LIBDIR=%{_libdir} \
      -DCMAKE_INSTALL_BINDIR=%{_bindir} -DCMAKE_INSTALL_SBINDIR=%{_sbindir} \
      -DCMAKE_INSTALL_SYSCONFDIR=%{_sysconfdir} -DCMAKE_INSTALL_MANDIR=%{_mandir} \
      -DENABLE_TOMAHAWK=on -DENABLE_MONITOR=on -DUSE_SYSTEM_MBEDTLS=off \
      -DENABLE_CACHE=on -DENABLE_TLS=on -DENABLE_RPROXY=on -DENABLE_XSLT=on \
      -DENABLE_IPV6=on -DENABLE_LOADCHECK=on -DENABLE_TOOLKIT=on \
      -DENABLE_ZLIB_SUPPORT=on -DUSE_PKCS11_HELPER_LIBRARY=on \
      -DUSE_STATIC_MBEDTLS_LIBRARY=on -DUSE_SHARED_MBEDTLS_LIBRARY=off
%__make %{?_smp_mflags}

%install
rm -rf %{buildroot}
mkdir -p  %{buildroot}
%__make install DESTDIR=%{buildroot}
mkdir -p %{buildroot}%{_unitdir}
mkdir -p %{buildroot}%{_sysconfdir}/logrotate.d/
%if %{use_systemd}
# install systemd-specific files
%{__mkdir} -p $RPM_BUILD_ROOT%{_unitdir}
%{__install} -m644 extra/debian/hiawatha.service %{buildroot}%{_unitdir}/hiawatha.service
%else
# install SYSV init stuff
%{__mkdir} -p $RPM_BUILD_ROOT%{_initrddir}
%{__install} -m644 extra/redhat/hiawatha $RPM_BUILD_ROOT%{_initrddir}/hiawatha
%endif
%{__install} -m644 logrotate.d/hiawatha %{buildroot}%{_sysconfdir}/logrotate.d/hiawatha
sed -i "s/#ServerId/ServerId/" %{buildroot}%{_sysconfdir}/hiawatha/hiawatha.conf
sed -i "s/www-data/hiawatha/" %{buildroot}%{_sysconfdir}/hiawatha/hiawatha.conf
sed -i "s/www-data www-data/hiawatha hiawatha/" %{buildroot}%{_sysconfdir}/logrotate.d/hiawatha
# Docs
%{__mkdir} -p %{buildroot}%{_defaultdocdir}/hiawatha
%{__install} -m644 ChangeLog %{buildroot}%{_defaultdocdir}/hiawatha/ChangeLog
%{__install} -m644 LICENSE %{buildroot}%{_defaultdocdir}/hiawatha/LICENSE
%{__install} -m644 README.md %{buildroot}%{_defaultdocdir}/hiawatha/README.md
# Extra
%{__mkdir} -p %{buildroot}%{_datadir}/hiawatha/letsencrypt/libraries
%{__install} -m755 extra/tls_make_ec %{buildroot}%{_datadir}/hiawatha/tls_make_ec
%{__install} -m755 extra/tls_make_rsa %{buildroot}%{_datadir}/hiawatha/tls_make_rsa
%{__install} -m755 extra/letsencrypt/letsencrypt %{buildroot}%{_datadir}/hiawatha/letsencrypt/letsencrypt
%{__install} -m644 extra/letsencrypt/letsencrypt.conf %{buildroot}%{_datadir}/hiawatha/letsencrypt/letsencrypt.conf
%{__install} -m644 extra/letsencrypt/README.txt %{buildroot}%{_datadir}/hiawatha/letsencrypt/README.txt
%{__install} -m644 extra/letsencrypt/INSTALL %{buildroot}%{_datadir}/hiawatha/letsencrypt/INSTALL
%{__install} -m644 extra/letsencrypt/LICENSE %{buildroot}%{_datadir}/hiawatha/letsencrypt/LICENSE
%{__install} -m644 extra/letsencrypt/libraries/acmev2.php %{buildroot}%{_datadir}/hiawatha/letsencrypt/libraries/acmev2.php
%{__install} -m644 extra/letsencrypt/libraries/config.php %{buildroot}%{_datadir}/hiawatha/letsencrypt/libraries/config.php
%{__install} -m644 extra/letsencrypt/libraries/hiawatha_config.php %{buildroot}%{_datadir}/hiawatha/letsencrypt/libraries/hiawatha_config.php
%{__install} -m644 extra/letsencrypt/libraries/http.php %{buildroot}%{_datadir}/hiawatha/letsencrypt/libraries/http.php
%{__install} -m644 extra/letsencrypt/libraries/https.php %{buildroot}%{_datadir}/hiawatha/letsencrypt/libraries/https.php
%{__install} -m644 extra/letsencrypt/libraries/letsencrypt.php %{buildroot}%{_datadir}/hiawatha/letsencrypt/libraries/letsencrypt.php
%{__install} -m644 extra/letsencrypt/libraries/logfile.php %{buildroot}%{_datadir}/hiawatha/letsencrypt/libraries/logfile.php
%{__install} -m644 extra/letsencrypt/libraries/openssl.conf %{buildroot}%{_datadir}/hiawatha/letsencrypt/libraries/openssl.conf
%{__install} -m644 extra/letsencrypt/libraries/rsa.php %{buildroot}%{_datadir}/hiawatha/letsencrypt/libraries/rsa.php

%pre
# Add the "hiawatha" user
getent group hiawatha >/dev/null || groupadd -r hiawatha
getent passwd hiawatha >/dev/null || \
    useradd -r -g hiawatha -d /var/www/hiawatha -s /sbin/nologin \
    -c "Hiawatha Web server" hiawatha

%post
if [ "$1" = 1 ]; then
# On install
%if %{use_systemd}
    /usr/bin/systemctl preset hiawatha.service >/dev/null 2>&1 ||:
    /usr/bin/systemctl start hiawatha
%else
    /sbin/chkconfig --add hiawatha
    /sbin/chkconfig hiawatha on
    /sbin/service hiawatha start
%endif
else
# On update
%if %{use_systemd}
    /usr/bin/systemctl daemon-reload
    /usr/bin/systemctl restart hiawatha
%else
    /sbin/service hiawatha restart
%endif
fi
exit 0

%preun
if [ "$1" = 0 ]; then
%if %{use_systemd}
    /usr/bin/systemctl --no-reload disable hiawatha.service >/dev/null 2>&1 ||:
    /usr/bin/systemctl stop hiawatha.service >/dev/null 2>&1 ||:
%else
    /sbin/service hiawatha stop
    /sbin/chkconfig --del hiawatha
%endif
fi
exit 0

%clean
rm -rf %{buildroot}

%files
%attr(755, root, root) %{_bindir}/ssi-cgi
%attr(755, root, root) %{_sbindir}/cgi-wrapper
%attr(755, root, root) %{_sbindir}/hiawatha
%attr(755, root, root) %{_sbindir}/wigwam
%attr(644, root, root) %{_mandir}/man1/cgi-wrapper.1.gz
%attr(644, root, root) %{_mandir}/man1/hiawatha.1.gz
%attr(644, root, root) %{_mandir}/man1/ssi-cgi.1.gz
%attr(644, root, root) %{_mandir}/man1/wigwam.1.gz
%attr(-, root, root) %{_localstatedir}/log/hiawatha/
%attr(-, root, root) %{_localstatedir}/www/hiawatha/
%attr(-, root, root) %{_defaultdocdir}/hiawatha/
%if %{use_systemd}
%attr(-, root, root) %{_unitdir}/
%else
%attr(-, root, root) %{_initrddir}/
%endif
%config(noreplace) %{_sysconfdir}/hiawatha
%config(noreplace) %{_sysconfdir}/logrotate.d/hiawatha
%exclude %{_libdir}/hiawatha

%files extra
%attr(-, root, root) %{_datadir}/hiawatha/

%changelog
* Fri Jan 25 2019 Paul Bernal <paul.bernal@cedia.org.ec> 10.8.3-2
- Added missing /usr/share/hiawatha/letsencrypt/libraries/logfile.php

* Tue Nov 13 2018 Ernesto Perez <ernesto.perez@cedia.org.ec> 10.8.3-1
- Upgraded to upstream 10.8.3

* Thu Mar 22 2018 Paul Bernal <paul.bernal@cedia.org.ec> 10.8-2
- Added support for compiling for el6 & el7 (%{use_systemd})
- Changed %build for using cmake3

* Thu Mar 22 2018 Paul Bernal <paul.bernal@cedia.org.ec> 10.8-1
- Changed Group to System Environment/Daemons
- Updated acme.php to acmev2.php on letsencrypt library
- Upgraded to upstream 10.8

* Wed Dec 20 2017 Ernesto Perez <ernesto.perez@cedia.org.ec> 10.7-1
- Upgraded to upstream 10.7

* Thu Apr 20 2017 Ernesto Perez <ernesto.perez@cedia.org.ec> 10.6-1
- Using Fedora specs to rebuild CentOS rpm so systemd for CentOS-7 will work
- Added php-process as a require for using letsencrypt
- Upgraded to upstream 10.6

* Mon Jan 30 2017 Marco Bignami <m.bignami@unknown-domain.no-ip.net> 10.5-1
 - Upgraded to upstream 10.5

* Wed Nov 23 2016 Marco Bignami <m.bignami@unknown-domain.no-ip.net> 10.4-2
 - Changed init script to upstram.

* Sun Oct 09 2016 Marco Bignami <m.bignami@unknown-domain.no-ip.net> 10.4-1
 - Upgraded to upstream 10.4

* Wed Jun 22 2016 Marco Bignami <m.bignami@unknown-domain.no-ip.net> 10.3-4
 - Fixed spec for auto reload of systemd unit
 - Created extra subpackage

* Wed Jun 22 2016 Marco Bignami <m.bignami@unknown-domain.no-ip.net> 10.3-3
 - Fixed spec to use internal mbedtls

* Wed Jun 22 2016 Marco Bignami <m.bignami@unknown-domain.no-ip.net> 10.3-2
 - Added group for EPEL build

* Wed Jun 22 2016 Marco Bignami <m.bignami@unknown-domain.no-ip.net> 10.3-1
 - Fixed spec for hiawatha-10.3

* Tue Jun 21 2016 Marco Bignami <m.bignami@unknown-domain.no-ip.net> 10.3-1
 - Created spec for hiawatha-10.3
